@@ -18,11 +18,11 @@ from fabric.context_managers import hide
 from pkg_resources import resource_stream
 
 from django_fabfile import __name__ as pkg_name
+from django_fabfile.security_groups import new_security_group
 from django_fabfile.utils import (
-    Config, StateNotChangedError, add_tags, config_temp_ssh,
-    get_descr_attr, get_inst_by_id, get_region_conn, get_snap_device,
-    get_snap_instance, get_snap_time, new_security_group,
-    timestamp, wait_for, wait_for_exists, wait_for_sudo)
+    Config, StateNotChangedError, add_tags, config_temp_ssh, get_descr_attr,
+    get_inst_by_id, get_region_conn, get_snap_device, get_snap_instance,
+    get_snap_time, timestamp, wait_for, wait_for_exists, wait_for_sudo)
 
 
 config = Config()
@@ -89,7 +89,8 @@ def create_instance(region_name='us-east-1', zone_name=None, key_pair=None,
 
 
 @contextmanager
-def create_temp_inst(region=None, zone=None, key_pair=None, security_groups='',                      synchronously=False):
+def create_temp_inst(region=None, zone=None, key_pair=None, security_groups='',
+                     synchronously=False):
     if region and zone:
         assert zone in get_region_conn(region.name).get_all_zones(), (
             '{0} doesn\'t belong to {1}'.format(zone, region))
